@@ -3,9 +3,9 @@
 
 var
   fs = require('fs'),
+  os = require('os'),
   path = require('path'),
   assertions = require('./assertions'),
-  rimraf = require('rimraf'),
   tmp = require('../lib/tmp');
 
 module.exports = function inbandStandard(isFile, beforeHook, sync = false) {
@@ -19,6 +19,7 @@ module.exports = function inbandStandard(isFile, beforeHook, sync = false) {
   describe('with mode', inbandStandardTests(null, { mode: 0o755 }, isFile, beforeHook, sync));
   describe('with multiple options', inbandStandardTests(null, { prefix: 'tmp-multiple', postfix: 'bar', mode: 0o750 }, isFile, beforeHook, sync));
   describe('with tmpdir option', inbandStandardTests(null, { tmpdir: path.join(tmp.tmpdir, 'tmp-external'), mode: 0o750 }, isFile, beforeHook, sync));
+  describe('with dir option', inbandStandardTests(null, { dir: os.tmpdir(), mode: 0o750 }, isFile, beforeHook, sync));
   if (isFile) {
     describe('with discardDescriptor', inbandStandardTests(null, { mode: testMode, discardDescriptor: true }, isFile, beforeHook, sync));
     describe('with detachDescriptor', inbandStandardTests(null, { mode: testMode, detachDescriptor: true }, isFile, beforeHook, sync));
@@ -86,7 +87,7 @@ function inbandStandardTests(testOpts, opts, isFile, beforeHook, sync = false) {
         } catch (err) {
           // important: remove file or dir unconditionally
           try {
-            rimraf.sync(this.topic.name);
+            fs.rmSync(this.topic.name, { recursive: true });
           } catch (_ignored) {
             // ignore
           }
@@ -101,7 +102,7 @@ function inbandStandardTests(testOpts, opts, isFile, beforeHook, sync = false) {
           try {
             assertions.assertDoesNotExist(self.topic.name);
           } catch (err) {
-            rimraf.sync(self.topic.name);
+            fs.rmSync(self.topic.name, { recursive: true });
             return done(err);
           }
           done();
